@@ -2,8 +2,6 @@ from datetime import timedelta
 from datetime import datetime
 import coursebox
 # import thtools
-import os
-import shutil
 from coursebox.thtools_base import list_dict2dict_list
 # import jinjafy
 import openpyxl
@@ -78,12 +76,12 @@ def get_enrolled_students():
         students2[id] = s2
     return students2
 
-
-def get_file_dir_or_template(filepath, templatepath):
-    thtools.ensure_dir_exists( os.path.dirname(filepath) )
-    if not os.path.exists(os.path.dirname):
-        shutil.copyfile(templatepath, filepath)
-
+# def get_file_dir_or_template(filepath, templatepath):
+#     dn =  os.path.dirname(filepath)
+#
+#     thtools.ensure_dir_exists(  )
+#     if not os.path.exists(os.path.dirname):
+#         shutil.copyfile(templatepath, filepath)
 
 def get_instructors():
     paths = get_paths()
@@ -267,7 +265,7 @@ def class_information():
     del gi['key']
     del gi['value']
 
-    from coursebox.core.citations import get_references
+    from snipper.citations import get_references
     if "pensum_bib" in gi:
         refs, nrefs = get_references(paths['02450public'] + "/" + gi['pensum_bib'], gi)
         d['references'], d['new_references'] = refs, nrefs
