@@ -12,19 +12,18 @@ from openpyxl.utils import get_column_letter
 import matplotlib.pyplot as plt
 import langdetect
 import xlwings as xw
-
-from thtools.coursebox.core.projects_info import get_output_file, INSTRUCTOR_ROW, STUDENT_ID_ROW, parse_column
-from thtools.coursebox.core.projects_info import EVALUATION_ROW_END, EVALUATION_ROW_START, WEIGHT_ROW_START, RANGE_MIN_COL, DELTA_ALLOWED_ROW
-from thtools.coursebox.core.info import get_paths, class_information, semester_id
-from thtools.coursebox.core import projects_info
-from thtools.coursebox.core.projects_plagiarism import plagiarism_checker
-
-from thtools.cache import cache_contains_dir, cache_update_dir
-from thtools.plot.plot_helpers import get_colors
+from coursebox.core.projects_info import get_output_file, INSTRUCTOR_ROW, STUDENT_ID_ROW, parse_column
+from coursebox.core.projects_info import EVALUATION_ROW_END, EVALUATION_ROW_START, WEIGHT_ROW_START, RANGE_MIN_COL, DELTA_ALLOWED_ROW
+from coursebox.core.info import get_paths, class_information, semester_id
+from coursebox.core import projects_info
+from coursebox.core.projects_plagiarism import plagiarism_checker
+from jinjafy.cache import cache_contains_dir, cache_update_dir
+from jinjafy.plot.plot_helpers import get_colors
 import time
-
 from collections import defaultdict
 import zipfile
+
+
 def get_dirs(zf):
     zip = zipfile.ZipFile(zf)
     fls = list(set([os.path.dirname(x) for x in zip.namelist()]))
@@ -35,7 +34,7 @@ def fix_handins_fuckup(project_id=2):
     """ Handle the problem with multiple hand-ins in DTU learn. """
     import zipfile
     paths = get_paths()
-    from thtools.coursebox.core.info import class_information
+    from coursebox.core.info import class_information
     info = class_information()
     zf = paths['instructor_project_evaluations'] + f"/zip{project_id}.zip"
 
