@@ -10,7 +10,7 @@ from jinjafy import jinjafy_template
 from coursebox.core.info_paths import get_paths
 from slider.legacy_importer import slide_to_image
 from slider.legacy_importer import li_import
-from slider.slider import set_svg_background_images
+from slider.slide import set_svg_background_images
 from coursebox.book.exam_includer import HOMEWORK_PROBLEMS
 from coursebox.core.info import class_information
 from coursebox.material.lecture_questions import lecture_question_compiler
